@@ -5,7 +5,7 @@ from typing import List, Union
 from pathlib import Path
 
 
-__version__ = "2022.6.23.1"
+__version__ = "2022.6.30.1"
 log_format = logging.Formatter(
     "[%(asctime)s] %(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
 )
@@ -92,6 +92,8 @@ def configure_logger(
 
     # 检查是否指定了新的console_handler处理器
     new_console_handler = False
+    if handlers is None:
+        handlers = list()
     for handler in handlers:
         if type(handler) == logging.StreamHandler:
             new_console_handler = True
