@@ -167,7 +167,18 @@ def rm(src_path: Union[str, Path], *args, **kwargs):
     """删除文件或目录
     :param src_path: str, 源文件或目录路径
     """
-    check_path_is_exits(src_path)
+    ignore_error = False
+    if "ignore_error" in kwargs:
+        ignore_error = kwargs["ignore_error"]
+
+    try:
+        check_path_is_exits(src_path)
+    except Exception as _err:
+        if ignore_error:
+            logger.warning(f"文件不存在，无需删除：{src_path}")
+            return
+        else:
+            raise _err
 
     # 统一转换成Path处理
     if isinstance(src_path, str):
@@ -181,6 +192,11 @@ def rm(src_path: Union[str, Path], *args, **kwargs):
     logger.info(f"删除成功：{src_path}")
 
 
+def rm_safe(src_path: Union[str, Path]):
+    """安全删除"""
+    rm(src_path=src_path, ignore_error=True)
+
+
 def rm_readonly(fn, tmp, info):
     """删除只读文件"""
     os.chmod(tmp, stat.S_IWRITE)
